<!DOCTYPE html>
<html lang="en" dir="ltr">
    <head>
        <meta charset="utf-8">
        <title>Unsubscribe</title>
    </head>
    <body>
        You have been unsubscribed from
        {{ tag.description|default:'these types of' }}
        emails.
    </body>
</html>
