# Generated by Django 2.1.2 on 2018-10-15 11:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Tag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('recipient', models.EmailField(max_length=255)),
                ('tag', models.CharField(max_length=36)),
                ('hash', models.CharField(max_length=36)),
                ('description', models.CharField(blank=True, max_length=100, null=True)),
                ('unsubscribed', models.BooleanField(default=False)),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='tag',
            unique_together={('tag', 'recipient')},
        ),
    ]
